@@ -49,7 +49,7 @@ class GStream(object):
         """
         if not self.sock:
             return
-        self.sock.shutdown(how)
+        safe_call(self.sock.shutdown, how)
 
     def set_close_callback(self, callback):
         """
